
# This is the server logic for a Shiny web application.
# You can find out more about building applications with Shiny here:
#
# http://shiny.rstudio.com
#

library(shiny)
#library(plotly)
library(ggplot2)
library(gridExtra)
library(data.table)
library(dplyr)


shinyServer(function(input, output, session) {
  

  ###########################################################
  #### Synthesis ############################################
  ###########################################################  
  
  
  output$incertDispo <- renderUI({
    #load(paste0("data/listRes_MIMI_plan_MPA_renamed.RData"))
    #load(paste0("data/listRes_MIMI_plan5400.RData"))
    uncChoice = c("Derive","Survie","Dispersion","RelationSR")
    selectizeInput("Incertitudes", "Selectionner les incertitudes à considérer :", choices = uncChoice,multiple = T,selected = NULL)
  })
  
  output$incertitudeExplicitee_couleur <- renderUI({
    uncertExp <- input$Incertitudes
    selectizeInput("Incertitude_explicitee_couleur", "Colorer les graphs selon les valeurs de (optionnel):", choices = c(PotentiellementChoisir ='',uncertExp),multiple = F,selected = NULL)
  })
  
  output$incertitudeExplicitee_pannel <- renderUI({
    uncertExp2 <- input$Incertitudes
    selectizeInput("Incertitude_explicitee_pannel", "Séparer les graphs selon les valeurs de (optionnel):", choices = c(PotentiellementChoisir ='',uncertExp2),multiple = F,selected = NULL)
  })
  
  output$incertDisposc <- renderUI({
    #load(paste0("data/listRes_MIMI_plan5400.RData"))
    uncChoice = c("Derive","Survie","Dispersion","RelationSR")
    selectizeInput("Incertitudessc", "Selectionner les incertitudes à considérer :", choices =uncChoice,multiple = T,selected = NULL)
  })
  
  
  listObj = list(Biomasse=2000,Captures=600,SSB=800)
  
  
  output$plot1 <- renderPlot({
    
    #load(paste0("data/listRes_MIMI_plan5400.RData"))
    load(paste0("data/listRes_MIMI_3101.RData"))
    
    if( is.null(unlist(input$Years))  | is.null(unlist(input$Results))){ #| is.null(input$Scenarios)
      return("Sélectionner les résultats et années à représenter")
    }else {
      ##########################################################
      # Synthesis graphs
      # per year, species
      # plot biomass, catch weight, discard and revenues
      #########################################################
      print(input$graphType)
      
      # User defines :
      # scenarios
      scs = "Référence"

      # uncertainties to display
      uncerts = c("Derive","Survie","Dispersion","RelationSR")# names(listRes[[1]])[which( ! names(listRes[[1]]) %in% c("simname","year","value","Scenarios"))]
      #uncerts = uncerts[-grep("_ref",uncerts)]
      print(uncerts)
      if(length( unlist(input$Incertitudes))==4) {NOuncs = character(0)
      }else {NOuncs = paste0(uncerts[which(! uncerts %in% unlist(input$Incertitudes))],"_ref")}
      
      # uncertainty scenario to explicitely display
      uncexp = ''
      if(length(input$Incertitude_explicitee_pannel) !=0) uncexp = input$Incertitude_explicitee_pannel
      
      # uncertainty scenario to explicitely display in different colors
      uncexpcol = 'none'
      if(length(input$Incertitude_explicitee_couleur) !=0) uncexpcol = input$Incertitude_explicitee_couleur
      
      # year
      vecYears = unlist(input$Years)
      if ("Toutes" %in% vecYears) {
        year = unique(listRes[[1]]$year)[order(unique(listRes[[1]]$year))]
        year = as.numeric(year) #unlist(input$Years))
      }else if("cumul" %in% vecYears){
        year = as.numeric(vecYears[-which(vecYears == "cumul")])
        
      }else year = as.numeric(vecYears)
      print(year)
      
      
      # Results to plot
      Results = unlist(input$Results)
      
      
      # Apply user's settings
      listRes2 = list()
      for(resname in Results){
        res = listRes[[resname]]
        res2 = res[which(res$Scenarios %in% scs & res$year %in% year),]
        print(NOuncs)
        if(length(NOuncs)!=0){ # some uncertainty sources are not considered : use base case
          if(length(NOuncs)>1) {res3 = res2[which(rowSums(res2[,NOuncs]) == 0) ,] # more than 1 uncertainty source is not considered
          } else { res3 = res2[which(res2[,NOuncs] == 0),]} # only one unecrtainty source is not considered
        }else res3 = res2
        res3$none <- 0
        listRes2[[resname]] <- res3
      }
      
      
      
      ###------------------------------------------------------------------------------
      # Plots
      
      plotlist = list()
      metricsList = c()
      for(resname in names(listRes2)){
        res = listRes2[[resname]]
        
        # if explicit uncertainty creates a new variable sc = Scenario x explicit_uncert
        if (uncexp !=''){res$sc = paste(res$Scenarios,res[,uncexp],sep="-")
        } else {res$sc = res$Scenarios}
        
        respop= res
        respop$basecase <- "pasBC"
        respop$basecase[which(rowSums(respop[,paste0(uncerts,"_ref")]) == 0)] <- "BC"
        respop$size <- 1
        respop$size[respop$basecase == "BC"] <- 2
        respop$simChar = paste0(respop$simname,"D",respop$Derive,"S",respop$Survie,"Di",respop$Dispersion,"SR","RelationSR")
        
        # Quantify uncertainty : 
        lastY <- respop %>% filter(year == max(year))
        rangeY <- range(lastY$value)
        ecartRelY <- (rangeY[2]-rangeY[1])/lastY$value[lastY$basecase == "BC"]
        refY <- c(rangeY[1]/lastY$value[lastY$basecase == "BC"],rangeY[2]/lastY$value[lastY$basecase == "BC"])
        metricsList <- c(metricsList,paste0(resname," :"), paste0("bornes min-max: ",round(rangeY[1])," - ",round(rangeY[2])), 
                         paste0("écart min-max relatif au cas de base : ",round(ecartRelY,2)),
                         paste0("bornes min-max relatives au cas de base : ",round(refY[1],2)," - ",round(refY[2],2)))
        
        # Functions for stat summary
        mean.quartile <- function(x){
          out <- c(mean(x)-sd(x),mean(x),mean(x)+sd(x))
          names(out) <- c("ymin","y","ymax")
          return(out)
        }
        
        median.quartile <- function(x){
          out <- quantile(x, probs = c(0.25,0.5,0.75))
          names(out) <- c("ymin","y","ymax")
          return(out)
        }
        
        set_dotsize = 0.1
        
        # recurrent base formula for the graphs
        ggbase <- ggplot(data=respop, aes(x= as.factor(year),y=value,group=simChar))+
          scale_size_manual(values=c(2,1))+
          theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
          xlab("years") + 
          scale_color_brewer(palette = "Paired")
        
        ggbase2 <- ggplot(data=respop, aes(x= as.factor(year),y=value))+
          scale_size_manual(values=c(2,1))+
          theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
          xlab("years") + 
          scale_color_brewer(palette = "Paired")
        
        # Shall objectives be added on the graph
        if(input$obj == TRUE){
          respop <- respop %>% mutate(obs=1,crit = if_else(value < listObj[[resname]], 1, 0),
                                      objectif_str = c("au-dessus","en-dessous")[crit+1])%>% 
            mutate(objectif=factor(objectif_str,levels = c("en-dessous","au-dessus")))
          globalRisque = sum(respop$crit)/length(respop$crit)
          Yrisk <- respop %>% group_by(year,objectif)%>% summarise(sumobs = sum(obs))%>% ungroup()%>%
            group_by(year) %>% mutate(risque = sumobs/sum(sumobs)*100)
          
          prisk <- ggplot(Yrisk,aes(x=year,y=risque,fill=objectif)) + geom_bar(stat="identity")+
            ggtitle(paste0(resname,"-Risque d'être sous l'objectif : " , round(globalRisque*100,2),"%" ))+
            geom_hline(yintercept = c(95,50),linetype = c("dotted","dashed"))+
            scale_fill_manual(values=c("red","green"))
          
          ggbase  <- ggbase +  geom_hline(yintercept = listObj[[resname]],colour="orange",size=2)
          ggbase2  <- ggbase2 +  geom_hline(yintercept = listObj[[resname]],colour="orange",size=2)
        
          #plotlist[[paste(resname,"risque",sep="-")]] <- prisk
        }
        
        # http://www.sthda.com/english/wiki/ggplot2-dot-plot-quick-start-guide-r-software-and-data-visualization
        
        # Test for the type of graph
        if('lignes'%in% input$graphType){
          # Plot
          gg <- ggbase +
            ggtitle( paste(paste(resname,input$graphType,sep="-")) ) 
          if(uncexpcol != ''){gg <- gg +
            geom_point(aes(color= as.factor(get(uncexpcol))))+
            geom_line(aes(color= as.factor(get(uncexpcol)))) #aes(linetype=basecase, size=basecase))+
          }else{gg <- gg + geom_point() + geom_line()}
          if(uncexp != ''){gg <- gg + facet_wrap(.~respop[,uncexp])
          }else {gg<- gg + 
            geom_line(data=respop%>% filter(basecase == "BC"),colour="turquoise")}
          
          plotlist[[paste(resname,1,sep="-")]] <- gg}
        
        if('enveloppe' %in% input$graphType){ # graph2
          
          if(uncexpcol != ''){gg <- ggplot(data=respop, aes(x= year,y=value,
                                       color=as.factor(get(uncexpcol)),group=as.factor(get(uncexpcol)),fill=as.factor(get(uncexpcol))))+
                                        stat_summary(fun=mean,geom="line",size=2)
          }else{gg <- ggplot(data=respop, aes(x= year,y=value)) +
            stat_summary(fun=mean,geom="line",size=2,colour="blue")}
          
          if(input$obj == TRUE){
            gg  <- gg +  geom_hline(yintercept = listObj[[resname]],colour="orange",size=2)
          }
          
          gg <- gg + 
            stat_summary(fun.data = mean.quartile,geom="ribbon",alpha=0.2)+
            geom_point(colour="black") + 
            scale_size_manual(values=c(2,1))+
            theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
            xlab("years") +
            ggtitle( paste(paste(resname,"enveloppe",sep="-")) )
          
          if(uncexp != ''){gg <- gg + facet_wrap(.~respop[,uncexp])}
          
          plotlist[[paste(resname,2,sep="-")]] <- gg }
        
        #https://r-graph-gallery.com/104-plot-lines-with-error-envelopes-ggplot2.html
        
        if ('points' %in% input$graphType){ # graph 1 TS brutes
          gg <- ggbase + ggtitle( paste(paste(resname,"points",sep="-")) )
          if(uncexpcol != ''){gg <- gg + geom_point(aes(colour= as.factor(get(uncexpcol))))
          }else {gg <- gg + geom_point()}
          if(uncexp != ''){gg <- gg + facet_wrap(.~respop[,uncexp])}
          
          plotlist[[paste(resname,3,sep="-")]] <- gg}
        
        if('dotplot' %in% input$graphType){
          # group does not work with dotplot
          gg <- ggbase2 +
            ggtitle( paste(paste(resname,"points alignés",sep="-")) )
          
          if(uncexpcol != ''){gg <- gg + geom_dotplot(binaxis='y', stackdir='center',aes(fill= as.factor(get(uncexpcol))),dotsize=set_dotsize,position=position_dodge(0.8))
          }else{gg <- gg + geom_dotplot(binaxis='y', stackdir='center',dotsize=set_dotsize)}
          if(uncexp != ''){gg <- gg + facet_wrap(.~respop[,uncexp])}
          
          plotlist[[paste(resname,4,sep="-")]] <- gg}
        
        if('violon'%in% input$graphType){ # violon
          
          gg <- ggbase2 + 
            geom_violin()+
            #geom_line(aes(group=simChar))+
            ggtitle( paste(paste(resname,"violon",sep="-")) ) 
         
          if(input$sansPts == FALSE){
          if(uncexpcol != ''){gg <- gg + geom_dotplot(binaxis='y', stackdir='center',
                              dotsize=set_dotsize,aes(fill=as.factor(get(uncexpcol))),position=position_dodge(0.8))
          }else{gg <- gg + geom_dotplot(binaxis='y', stackdir='center',dotsize=set_dotsize,fill="white")}}
          if(uncexp != ''){ gg <- gg + facet_wrap(.~respop[,uncexp])}
          
          plotlist[[paste(resname,5,sep="-")]] <- gg}
        
        if('densite' %in% input$graphType){
          if(uncexpcol != ''){ gg <- ggplot(data=respop, aes(x=value,fill=as.factor(get(uncexpcol)), 
                                                      colour=as.factor(get(uncexpcol))))+
            geom_density(alpha=.2,size=1)+
            scale_color_brewer(palette = "Paired")+
            scale_fill_brewer(palette = "Paired")+geom_vline(xintercept = listObj[[resname]])+
            coord_flip()+ facet_wrap(.~year,ncol=5,scale="free_x")
          
          }else {
            gg <- ggplot(data=respop, aes(x=value))+ 
              geom_density(alpha=.2,size=1) + coord_flip()+ facet_wrap(.~year,ncol=5,scale="free_x")
            if(input$obj == T){
              gg <- gg + geom_vline(xintercept = listObj[[resname]],colour="orange",size=2)
            }
          }
          gg <- gg + scale_size_manual(values=c(2,1))+
            theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
            xlab("years") +ggtitle(paste(resname,"densité",sep="-"))
          
          plotlist[[paste(resname,6,sep="-")]] <- gg}
        
        if('fourchettes' %in% input$graphType){ # POINT RANGE
          
          gg <- ggbase2 + 
            stat_summary(fun.data = mean.quartile,geom="pointrange", color="blue",size=2)+
            geom_line() +  stat_summary(fun = "median", geom = "point", size=4,colour="purple")+
            ggtitle( paste(paste(resname,"Fourchettes",sep="-")) )
          
          if(input$sansPts == FALSE){
          if(uncexpcol != ''){gg <- gg +
            geom_dotplot(binaxis='y', stackdir='center',aes(fill=as.factor(get(uncexpcol))),dotsize=set_dotsize,position=position_dodge(0.8))
          }else{gg <- gg + geom_dotplot(binaxis='y', stackdir='center',fill="white",dotsize=set_dotsize)}}
          
          if(uncexp != ''){gg <- gg + facet_wrap(.~respop[,uncexp])}
          
          
          plotlist[[paste(resname,7,sep="-")]] <- gg}
        
        if('boite'%in% input$graphType){ # CROSSBAR
          if(input$sansPts == FALSE){
            if(uncexpcol != ''){gg <- ggbase2 + geom_dotplot(binaxis='y', stackdir='center',dotsize=set_dotsize,aes(fill=as.factor(get(uncexpcol))),position=position_dodge(0.8))
            }else{gg <- ggbase2 + geom_dotplot(binaxis='y', stackdir='center',dotsize=set_dotsize,fill="white")}
          }else{gg<- ggbase2}
          
          
          if(uncexp != ''){ gg <- gg + facet_wrap(.~respop[,uncexp])}
          
          gg <- gg +
            #geom_dotplot(binaxis='y', stackdir='center',aes(fill=Scenarios))+
            stat_summary(fun = mean,geom="point", color="blue",size=2)+
            stat_summary(fun.data = median.quartile,geom="crossbar", width=0.5,size=1,color="purple")+
            ggtitle( paste(paste(resname,'boite',sep="-")) ) 
          
          if(uncexp != ''){ gg <- gg + facet_wrap(.~respop[,uncexp])}
          plotlist[[paste(resname,8,sep="-")]] <- gg}
        
        if('boite-moustache'%in% input$graphType){
          
          ff <- function(x) {
            r <- quantile(x, probs = c(0, 0.05, 0.5, 0.95, 1))
            names(r) <- c("ymin", "lower", "middle", "upper", "ymax")
            r
          }
          
          gg <- ggbase2 + #geom_boxplot(colour="purple")+
            stat_summary(fun=mean, geom="point",color="blue", size=3)+
            stat_summary(fun.data = ff, geom="boxplot", position=position_dodge(1),colour="purple")+
            ggtitle( paste(paste(resname,'boiteMoustache',sep="-")) ) 
          
          if (input$sansPts==FALSE){
          if(uncexpcol != ''){gg <- gg + geom_dotplot(binaxis='y', stackdir='center',dotsize=set_dotsize,aes(fill=as.factor(get(uncexpcol))),position=position_dodge(0.8))
          }else{gg <- gg + geom_dotplot(binaxis='y', stackdir='center',dotsize=set_dotsize,fill="white")}}
          
          if(uncexp != ''){ gg <- gg + facet_wrap(.~respop[,uncexp])}
          plotlist[[paste(resname,9,sep="-")]] <- gg}
        
 
        #do.call("grid.arrange",c(plotlist))
       
      }# fin du for resnames
      if(input$stats == TRUE){
        ymetr = length(listRes2)*4
        summaryMetrics <- ggplot()+aes(x=c(1),y=c(ymetr:1),label=metricsList)+geom_text()+ theme_bw()+ theme_void()+
          ggtitle("Mesures d'incertitude")+ylim(0,ymetr+1)
        plotlist[["metrics"]] <- summaryMetrics}
    print(names(plotlist))
      do.call("grid.arrange",c(plotlist))
      
    }# fin de if inputs null     
  })# fin de plot 1
  
  
  
  #####################################################################
  ######### scenarios ###############################################
  ####################################################################
  
  output$plot2 <- renderPlot({
    
    #load(paste0("data/listRes_MIMI_plan5400.RData"))
    load(paste0("data/listRes_MIMI_3101.RData"))
    
    if( is.null(unlist(input$Years2))  | is.null(unlist(input$Results2))  | is.null(unlist(input$Scenarios))){ #| is.null(input$Scenarios)
      return("Sélectionner les résultats et années à représenter")
    }else {

      # User defines :
      # scenarios
      scs = input$Scenarios
      print(scs)
      
      # uncertainties to display
      uncChoice = c("Derive","Survie","Dispersion","RelationSR")
      uncerts = uncChoice#names(listRes[[1]])[which( names(listRes[[1]]) %in% uncChoice)]
      if(length(unlist(input$Incertitudessc))==4) { NOuncs = character(0)
      } else {NOuncs = uncerts[which(! uncerts %in% unlist(input$Incertitudessc))]}
      
      # uncertainty scenario to explicitely display
      uncexp = ''
      if(length(input$Incertitude_explicitee_pannelsc) !=0) uncexp = input$Incertitude_explicitee_pannelsc
      
      
      # year
      vecYears = unlist(input$Years2)
      if ("Toutes" %in% vecYears) {
        year = unique(listRes[[1]]$year)[order(unique(listRes[[1]]$year))]
        year = as.numeric(year) #unlist(input$Years))
      }else if("cumul" %in% vecYears){
        year = as.numeric(vecYears[-which(vecYears == "cumul")])
        
      }else year = as.numeric(vecYears)
      print(year)
      
      
      # Results to plot
      Results = unlist(input$Results2)
      
      
      # Apply user's settings
      listRes2 = list()
      for(resname in Results){
        res = listRes[[resname]]
        res2 = res[which(res$Scenarios %in% scs & res$year %in% year),]
        print(NOuncs)
        if(length(NOuncs)!=0){ # some uncertainty sources are not considered : use base case
          if(length(NOuncs)>1) {res3 = res2[which(rowSums(res2[,paste0(NOuncs,"_ref")]) == 0) ,] # more than 1 uncertainty source is not considered
          } else { res3 = res2[which(res2[,paste0(NOuncs,"_ref")] == 0),]} # only one unecrtainty source is not considered
        }else res3 = res2
        res3$none <- 0
        listRes2[[resname]] <- res3
      }

      
      
      ###------------------------------------------------------------------------------
      # Plots
      
      plotlist2 = list()
      for(resname in names(listRes2)){
        respop = listRes2[[resname]]

        respop$basecase <- "pasBC"
        respop$basecase[which(rowSums(respop[,paste0(uncerts,"_ref")]) == 0)] <- "BC"
        respop$size <- 1
        respop$size[respop$basecase == "BC"] <- 2
        respop$simChar = paste0(respop$Scenarios,respop$simname,"R",respop$Recrutement,"C",respop$Connectivite,"E",respop$Eff_initiaux)
        respop <- respop %>% 
          mutate(Scenarios = factor(Scenarios,levels = c("Référence","TAC","MPA")))
        
        # Functions for stat summary
        mean.quartile <- function(x){
          sdt = input$sdt
          out <- c(mean(x)-sdt*sd(x),mean(x),mean(x)+sdt*sd(x))
          names(out) <- c("ymin","y","ymax")
          return(out)
        }
        
        median.quartile <- function(x){
          out <- quantile(x, probs = c(0.25,0.5,0.75))
          names(out) <- c("ymin","y","ymax")
          return(out)
        }
        
        # recurrent base formula for the graphs
        ggbaseY <- ggplot(data=respop, aes(x= year,y=value,colour=Scenarios))+
          scale_size_manual(values=c(2,1))+
          theme(panel.grid.major = element_blank(),text = element_text(size=15))+
          xlab("years") +  geom_hline(yintercept = listObj[[resname]])+
          scale_colour_manual(values=c("#999999", "#E69F00", "#56B4E9"))
        
          ggbaseY2 <- ggplot(data=respop, aes(x= as.factor(year),y=value,colour=Scenarios))+
          scale_size_manual(values=c(2,1))+
          theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
          xlab("years") +  geom_hline(yintercept = listObj[[resname]])+
          scale_colour_manual(values=c("#999999", "#E69F00", "#56B4E9"))

          ggbaseSc <- ggplot(data=respop, aes(x= Scenarios,y=value,colour=Scenarios))+
          scale_size_manual(values=c(2,1))+
          theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
          xlab("Scenarios") +  geom_hline(yintercept = listObj[[resname]])+
            scale_colour_manual(values=c("#999999", "#E69F00", "#56B4E9"))
        
        
        # Shall objectives be added on the graph
          respop <- respop %>% mutate(obs=1,crit = if_else(value < listObj[[resname]], 1, 0),
                                      objectif_str = c("au-dessus","en-dessous")[crit+1])%>% 
            mutate(objectif=factor(objectif_str,levels = c("en-dessous","au-dessus")))
          Yrisk <- respop %>% group_by(Scenarios,objectif)%>% summarise(sumobs = sum(obs))%>% ungroup()%>%
            group_by(Scenarios) %>% mutate(risque = sumobs/sum(sumobs)*100)
          
          prisk2 <- ggplot(Yrisk,aes(x=Scenarios,y=risque,fill=objectif)) + geom_bar(stat="identity")+
            ggtitle(paste0("Risque d'être sous l'objectif"))+
            geom_hline(yintercept = c(95,50),linetype = c("dotted","dashed"))+
            scale_fill_manual(values=c( "red","green"))+
            ggtitle(paste0(resname,"-Risque"))
          
          plotlist2[[paste(resname,"risque",sep="-")]] <- prisk2
        
          ########################################################################
          #plots
  
          if('lignes'%in% input$graphType2){
            if(length(year) >1){
            g1 <- ggbaseY + 
            ggtitle(paste0(resname,"-lignes"))+
            geom_line(aes(group=simChar),linetype=2,size=0.5) + geom_point() 
            #stat_summary(fun.data = mean.quartile,geom="pointrange", size=2)+
            }else{
              g1 <- ggbaseSc + geom_point(position=position_dodge(0.5))+
                ggtitle(paste0(resname,"-points"))
            }
            plotlist2[[paste(resname,1,sep="-")]] <- g1 
    
          }
          
          if('enveloppe' %in% input$graphType2 & length(year >1)){ # graph2
            
            g2 <- ggplot(data=respop, aes(x= year,y=value,group = Scenarios,fill=Scenarios, colour=Scenarios)) +
              stat_summary(fun=mean,geom="line",size=2)+
              stat_summary(fun.data = mean.quartile,geom="ribbon",alpha=0.2)+
              #geom_point(colour="black") + 
              scale_size_manual(values=c(2,1))+
              theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
              xlab("years") +geom_hline(yintercept = listObj[[resname]])+
              ggtitle( paste(paste(resname,"enveloppe",sep="-")) )+
              scale_fill_manual(values=c("#999999", "#E69F00", "#56B4E9"))+
              scale_colour_manual(values=c("#999999", "#E69F00", "#56B4E9"))
            
            plotlist2[[paste(resname,2,sep="-")]] <- g2 }
            
            
          if('dotplot' %in% input$graphType2){
            g3 <- ggbaseY2 +
            geom_dotplot(binaxis='y', stackdir='center',aes(fill= Scenarios),dotsize=0.01,position=position_dodge(0.8))+
            ggtitle( paste(paste(resname,"points alignés",sep="-")) )
            
            plotlist2[[paste(resname,3,sep="-")]] <- g3 }
            
          if('violon'%in% input$graphType2){  
            g4 <- ggbaseY2 + geom_violin(scale="width")+
            ggtitle( paste(paste(resname,"violons",sep="-")) )
            
            plotlist2[[paste(resname,4,sep="-")]] <- g4
          }
          
          if('densite' %in% input$graphType2){
            
            g5 <- ggplot(data=respop, aes(x=value,fill=Scenarios, colour=Scenarios))+
            geom_density(alpha=.2,size=1) +xlab("years") +
            geom_vline(xintercept = listObj[[resname]])+
            theme(panel.grid.major = element_blank(),text = element_text(size=15),legend.position = "none")+
            scale_colour_manual(values=c("#999999", "#E69F00", "#56B4E9"))+
            scale_fill_manual(values=c("#999999", "#E69F00", "#56B4E9"))+ coord_flip()+
            ggtitle(paste0(resname,"-densite"))+facet_wrap(.~year,ncol=5,scale="free_x") 
            
            plotlist2[[paste(resname,5,sep="-")]] <- g5
          }  
            
          if('fourchettes' %in% input$graphType2){
            g6 <- ggbaseY2 + stat_summary(fun.data = mean.quartile,geom="pointrange",
                                          size=1,position=position_dodge(0.5))+
              ggtitle(paste0(resname,"-fourchettes"))
            plotlist2[[paste(resname,6,sep="-")]] <- g6
          }
          
          if('boite-moustache'%in% input$graphType2){
            ff <- function(x) {
              pr = input$pr
              r <- quantile(x, probs = c(0, 1-pr/100, 0.5, pr/100, 1))
              names(r) <- c("ymin", "lower", "middle", "upper", "ymax")
              r
            }
            
            g7 <- ggbaseY2 + 
              stat_summary(fun.data = ff, geom="boxplot", position=position_dodge(0.8))+
              ggtitle(paste0(resname,"-boiteMoustache"))
          
            plotlist2[[paste(resname,7,sep="-")]] <- g7
          }
          
          do.call("grid.arrange",c(plotlist2)) 
          
          
      }# for resname
        
    } #if is null
  
  
  }) # output 2

}) #serveur
