
# This is the user-interface definition of a Shiny web application.
# You can find out more about building applications with Shiny here:
#
# http://shiny.rstudio.com
#


library(shiny)
#synth = get(load(paste0("./data/listRes_MIMI_plan5400.RData")))
synth = get(load(paste0("./data/listRes_MIMI_3101.RData")))


shinyUI((
    navbarPage("MIMI représentation de l'incertitude",
               tabPanel("Presentation",
                        
                        mainPanel(
                            h1("Exploration des représentations de l'incertitude des simulations avec le modèle ISIS-Fish"),
                            h2("Auteur: S. Lehuta, Ifremer"),
                            h2("Projet MIMI - 2023"),
                            h3("Pour plus d'informations concernant ISIS-Fish : isis-fish.org"),
                             
                        )
                        
                        
               ),
               tabPanel("Un scénario",
                        sidebarLayout(
                            sidebarPanel(
                                selectizeInput("Results", "Selectionner les resultats:", choices = unique(names(synth)),multiple = T),
                                selectizeInput("Years", "Selectionner les années:", choices = c("Toutes","cumul",2023:2027),multiple = T),
                                uiOutput("incertDispo"),
                                uiOutput("incertitudeExplicitee_couleur"),
                                uiOutput("incertitudeExplicitee_pannel"),

                                checkboxGroupInput("graphType", label = h3("Choix de la représentation à utiliser:"), 
                                                   choices = list("lignes" = "lignes","enveloppe"="enveloppe","points 1" = "points","points 2" = "dotplot" ,
                                                                  "violon" = "violon","densité"="densite","fourchettes" = "fourchettes","boite"="boite", 
                                                                  "boite-moustache"="boite-moustache"),
                                                   selected = "lignes"),
                                checkboxInput(inputId = "sansPts",label = "Retirer les points", 
                                              value = FALSE),
                                checkboxInput(inputId = "obj",label = "Ajouter les objectifs", 
                                              value = FALSE),
                                checkboxInput(inputId = "stats",label = "Ajouter les stats", 
                                              value = TRUE),
                                
                                hr(),
                                fluidRow(column(3, verbatimTextOutput("value")))
                                
                            )
                            ,
                            mainPanel(
                                #plotlyOutput('plot1',height=900,width="100%")
                                plotOutput('plot1',height=900,width="100%")
                            ))
                        ),
               tabPanel("Plusieurs scénarios",
                        sidebarLayout(
                          sidebarPanel(
                            selectizeInput("Results2", "Selectionner les resultats:", choices = unique(names(synth)),multiple = T),
                            selectizeInput("Years2", "Selectionner les années:", choices = c("Toutes","cumul",2023:2027),multiple = T),
                            selectizeInput("Scenarios", "Selectionner le(s) scénarios de gestion :", choices = unique(synth[[1]]$Scenarios),multiple = T),
                            uiOutput("incertDisposc"),
                            checkboxGroupInput("graphType2", label = h3("Choix de la représentation à utiliser:"), 
                                               choices = list("lignes" = "lignes","enveloppe"="enveloppe", "points 2" = "dotplot" ,
                                                              "violon" = "violon","densité"="densite","fourchettes" = "fourchettes", 
                                                              "boite-moustache"="boite-moustache"),
                                               selected = "lignes"),
                            sliderInput("sdt", "Niveau de confiance  fourchettes (x fois écart-type):",
                                        min = 1, max = 3, value = 1),
                            sliderInput("pr", "Niveau de confiance boite à moustache (%):",
                                        min = 50, max = 100, value = 75)
                            

                          ),
                        mainPanel(
                          plotOutput('plot2',height=900,width="100%")
                        )

              ))
                            
          )
                
))
